From e44aeca183a491179b346b0cbdbdd6172ab921cc Mon Sep 17 00:00:00 2001
From: Josef Glatz <josefglatz@gmail.com>
Date: Sun, 25 Jun 2017 10:03:11 +0200
Subject: [PATCH] [BUGFIX] iconIdentifier for custom system information panel
 items

An iconIdentifier is needed since the icon generation is
moved to the Fluid template. The third parameter of
addSystemInformation() needs to be an iconIdentifier
instead of an rendered icon html markup.

Resolves: #81694
Related: #80554
Releases: master, 8.7
Change-Id: Ib6b07281196b5ecda2de07b8d6328b524e08f038
Reviewed-on: https://review.typo3.org/53321
Reviewed-by: Frank Naegler <frank.naegler@typo3.org>
Tested-by: TYPO3com <no-reply@typo3.com>
Reviewed-by: Andreas Fernandez <typo3@scripting-base.de>
Tested-by: Frank Naegler <frank.naegler@typo3.org>
Reviewed-by: Markus Klein <markus.klein@typo3.org>
Tested-by: Markus Klein <markus.klein@typo3.org>
---
 .../Backend/ToolbarItems/SystemInformationToolbarItem.php   | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/typo3/sysext/backend/Classes/Backend/ToolbarItems/SystemInformationToolbarItem.php b/typo3/sysext/backend/Classes/Backend/ToolbarItems/SystemInformationToolbarItem.php
index 1e6375bdeb8f..78bcfb93f1ac 100644
--- a/typo3/sysext/backend/Classes/Backend/ToolbarItems/SystemInformationToolbarItem.php
+++ b/typo3/sysext/backend/Classes/Backend/ToolbarItems/SystemInformationToolbarItem.php
@@ -300,15 +300,15 @@ class SystemInformationToolbarItem implements ToolbarItemInterface
      *
      * @param string $title The title of this system information
      * @param string $value The associated value
      * @param string $icon The icon html
      * @param string $status The status of this system information
      */
-    public function addSystemInformation($title, $value, $icon, $status = InformationStatus::STATUS_NOTICE)
+    public function addSystemInformation($title, $value, $iconIdentifier, $status = InformationStatus::STATUS_NOTICE)
     {
         $this->systemInformation[] = [
             'title' => $title,
             'value' => $value,
-            'icon' => $icon,
+            'iconIdentifier' => $iconIdentifier,
             'status' => $status
         ];
     }
@@ -300,15 +300,15 @@ class SystemInformationToolbarItem implements ToolbarItemInterface
      * @param string $title The title of this system information
      * @param string $value The associated value
-     * @param string $icon The icon html
+     * @param string $iconIdentifier The icon identifier
      * @param string $status The status of this system information
      */
-- 
GitLab